#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
阿里云百炼-通义万相图像生成MCP服务器

本包提供了通义万相文生图V2版API的MCP服务器实现，支持：
- 文生图功能
- 多种模型选择
- 正向和反向提示词
- 自定义图像尺寸和生成数量

官方文档：https://help.aliyun.com/zh/model-studio/text-to-image-v2-api-reference

Author: John Chen
"""

__version__ = "1.0.3"
__author__ = "John Chen"
__email__ = "john.chen@example.com"
__description__ = "阿里云百炼-通义万相图像生成MCP服务器"


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
阿里云百炼-通义万相图像生成MCP服务器测试用例

本模块包含对图像生成MCP服务器的冒烟测试，验证以下功能：
- 服务器初始化
- 工具注册和列表
- 文生图V2版功能
- 参数验证
- 错误处理
- DashScope SDK集成

作者: SOLO Coding
版本: 1.0.0
"""

import asyncio
import json
import os
import sys
import unittest
from unittest.mock import AsyncMock, MagicMock, patch
from typing import Dict, Any

# 添加源代码路径到Python路径
sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'src'))

from mcp_server_bailian_image.server import (
    BailianImageServer,
    SUPPORTED_MODELS,
    SUPPORTED_SIZES
)


class TestBailianImageServer(unittest.TestCase):
    """
    阿里云百炼-通义万相图像生成MCP服务器测试类
    
    测试服务器的基本功能，包括初始化、工具注册、API调用等。
    使用mock避免实际的API调用，确保测试可以在没有API密钥的情况下运行。
    """

    def setUp(self):
        """
        测试前的准备工作
        
        创建测试用的服务器实例，使用模拟的API密钥。
        """
        self.test_api_key = "test_api_key_12345"
        
        # 模拟DashScope模块，避免实际导入
        with patch('mcp_server_bailian_image.server.dashscope') as mock_dashscope:
            mock_dashscope.api_key = None
            self.server = BailianImageServer(self.test_api_key)
        
        # 模拟的API响应数据
        self.mock_success_response = MagicMock()
        self.mock_success_response.status_code = 200
        self.mock_success_response.output = MagicMock()
        self.mock_success_response.output.task_id = "test_task_12345"
        self.mock_success_response.output.results = [
            MagicMock(url="https://example.com/generated_image1.jpg"),
            MagicMock(url="https://example.com/generated_image2.jpg")
        ]
        
        self.mock_error_response = MagicMock()
        self.mock_error_response.status_code = 400
        self.mock_error_response.message = "Invalid parameters"

    def test_server_initialization(self):
        """
        测试服务器初始化
        
        验证服务器能够正确初始化，包括API密钥设置和基本属性。
        """
        self.assertEqual(self.server.api_key, self.test_api_key)
        self.assertIsNotNone(self.server.server)
        self.assertEqual(self.server.server.name, "bailian-image")

    def test_supported_models_and_sizes(self):
        """
        测试支持的模型和尺寸常量
        
        验证预定义的模型列表和尺寸列表是否正确。
        """
        # 验证支持的模型
        expected_models = [
            "wan2.2-t2i-flash",
            "wan2.2-t2i-plus",
            "wanx2.1-t2i-turbo",
            "wanx2.1-t2i-plus",
            "wanx2.0-t2i-turbo"
        ]
        self.assertEqual(SUPPORTED_MODELS, expected_models)
        
        # 验证支持的尺寸
        expected_sizes = [
            "512*512", "512*768", "512*1024", "768*512", "768*768", "768*1024",
            "1024*512", "1024*768", "1024*1024", "1024*1440", "1440*1024"
        ]
        self.assertEqual(SUPPORTED_SIZES, expected_sizes)

    @patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call')
    async def test_text2imagev2_basic(self, mock_call):
        """
        测试基本的文生图功能
        
        验证能够正确调用文生图V2版API，包括基本参数处理。
        
        Args:
            mock_call: 模拟的DashScope ImageSynthesis.call方法
        """
        # 设置模拟返回值
        mock_call.return_value = self.mock_success_response
        
        # 测试参数
        prompt = "一只可爱的小猫，坐在花园里，阳光明媚"
        
        # 调用方法
        result = await self.server._text2imagev2(prompt=prompt)
        
        # 验证结果
        self.assertEqual(result["status"], "success")
        self.assertEqual(result["model"], "wan2.2-t2i-flash")  # 默认模型
        self.assertEqual(result["input"]["prompt"], prompt)
        self.assertEqual(result["parameters"]["size"], "1024*1024")  # 默认尺寸
        self.assertEqual(result["parameters"]["n"], 1)  # 默认数量
        self.assertEqual(len(result["output"]["results"]), 2)  # 模拟返回2张图片
        
        # 验证API调用参数
        mock_call.assert_called_once_with(
            model="wan2.2-t2i-flash",
            prompt=prompt,
            negative_prompt=None,
            size="1024*1024",
            n=1
        )

    @patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call')
    async def test_text2imagev2_with_negative_prompt(self, mock_call):
        """
        测试带反向提示词的文生图功能
        
        验证能够正确处理反向提示词参数。
        
        Args:
            mock_call: 模拟的DashScope ImageSynthesis.call方法
        """
        # 设置模拟返回值
        mock_call.return_value = self.mock_success_response
        
        # 测试参数
        prompt = "一幅美丽的风景画"
        negative_prompt = "低分辨率，模糊，错误，最差质量"
        
        # 调用方法
        result = await self.server._text2imagev2(
            prompt=prompt,
            negative_prompt=negative_prompt
        )
        
        # 验证结果
        self.assertEqual(result["status"], "success")
        self.assertEqual(result["input"]["prompt"], prompt)
        self.assertEqual(result["input"]["negative_prompt"], negative_prompt)
        
        # 验证API调用参数
        mock_call.assert_called_once_with(
            model="wan2.2-t2i-flash",
            prompt=prompt,
            negative_prompt=negative_prompt,
            size="1024*1024",
            n=1
        )

    @patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call')
    async def test_text2imagev2_custom_parameters(self, mock_call):
        """
        测试自定义参数的文生图功能
        
        验证能够正确处理自定义模型、尺寸和数量参数。
        
        Args:
            mock_call: 模拟的DashScope ImageSynthesis.call方法
        """
        # 设置模拟返回值
        mock_call.return_value = self.mock_success_response
        
        # 测试参数
        prompt = "科幻城市，未来感，高科技"
        model = "wan2.2-t2i-plus"
        size = "1440*1024"
        n = 3
        
        # 调用方法
        result = await self.server._text2imagev2(
            prompt=prompt,
            model=model,
            size=size,
            n=n
        )
        
        # 验证结果
        self.assertEqual(result["status"], "success")
        self.assertEqual(result["model"], model)
        self.assertEqual(result["parameters"]["size"], size)
        self.assertEqual(result["parameters"]["n"], n)
        
        # 验证API调用参数
        mock_call.assert_called_once_with(
            model=model,
            prompt=prompt,
            negative_prompt=None,
            size=size,
            n=n
        )

    async def test_text2imagev2_invalid_model(self):
        """
        测试无效模型参数的处理
        
        验证当提供不支持的模型时，能够正确返回错误信息。
        """
        # 测试参数
        prompt = "测试图像"
        invalid_model = "invalid_model_name"
        
        # 调用方法
        result = await self.server._text2imagev2(
            prompt=prompt,
            model=invalid_model
        )
        
        # 验证错误结果
        self.assertEqual(result["status"], "error")
        self.assertIn("不支持的模型", result["error"])
        self.assertEqual(result["model"], invalid_model)

    async def test_text2imagev2_invalid_size(self):
        """
        测试无效尺寸参数的处理
        
        验证当提供不支持的图像尺寸时，能够正确返回错误信息。
        """
        # 测试参数
        prompt = "测试图像"
        invalid_size = "999*999"
        
        # 调用方法
        result = await self.server._text2imagev2(
            prompt=prompt,
            size=invalid_size
        )
        
        # 验证错误结果
        self.assertEqual(result["status"], "error")
        self.assertIn("不支持的图像尺寸", result["error"])

    async def test_text2imagev2_invalid_count(self):
        """
        测试无效数量参数的处理
        
        验证当提供超出范围的生成数量时，能够正确返回错误信息。
        """
        # 测试参数
        prompt = "测试图像"
        invalid_n = 10  # 超出1-4的范围
        
        # 调用方法
        result = await self.server._text2imagev2(
            prompt=prompt,
            n=invalid_n
        )
        
        # 验证错误结果
        self.assertEqual(result["status"], "error")
        self.assertIn("生成数量必须在1-4之间", result["error"])

    @patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call')
    async def test_text2imagev2_api_error(self, mock_call):
        """
        测试API调用错误的处理
        
        验证当DashScope API返回错误时，能够正确处理并返回错误信息。
        
        Args:
            mock_call: 模拟的DashScope ImageSynthesis.call方法
        """
        # 设置模拟错误返回值
        mock_call.return_value = self.mock_error_response
        
        # 测试参数
        prompt = "测试图像"
        
        # 调用方法
        result = await self.server._text2imagev2(prompt=prompt)
        
        # 验证错误结果
        self.assertEqual(result["status"], "error")
        self.assertIn("API调用失败", result["error"])
        self.assertIn("400", result["error"])  # 状态码

    def test_parameter_validation_edge_cases(self):
        """
        测试参数验证的边界情况
        
        验证各种边界参数值的处理。
        """
        # 测试最小和最大生成数量
        async def test_min_max_count():
            # 最小值：1（有效值，应该成功）
            with patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call') as mock_call:
                mock_call.return_value = self.mock_success_response
                result_min = await self.server._text2imagev2(prompt="test", n=1)
                self.assertEqual(result_min["status"], "success")
            
            # 最大值：4（有效值，应该成功）
            with patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call') as mock_call:
                mock_call.return_value = self.mock_success_response
                result_max = await self.server._text2imagev2(prompt="test", n=4)
                self.assertEqual(result_max["status"], "success")
            
            # 超出范围：0（无效值，应该失败）
            result_zero = await self.server._text2imagev2(prompt="test", n=0)
            self.assertEqual(result_zero["status"], "error")
            
            # 超出范围：5（无效值，应该失败）
            result_five = await self.server._text2imagev2(prompt="test", n=5)
            self.assertEqual(result_five["status"], "error")
        
        asyncio.run(test_min_max_count())

    def test_all_supported_models(self):
        """
        测试所有支持的模型
        
        验证所有预定义的模型都能正确处理。
        """
        async def test_models():
            with patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call') as mock_call:
                mock_call.return_value = self.mock_success_response
                
                for model in SUPPORTED_MODELS:
                    result = await self.server._text2imagev2(
                        prompt="测试",
                        model=model
                    )
                    self.assertEqual(result["status"], "success")
                    self.assertEqual(result["model"], model)
        
        asyncio.run(test_models())

    def test_all_supported_sizes(self):
        """
        测试所有支持的尺寸
        
        验证所有预定义的图像尺寸都能正确处理。
        """
        async def test_sizes():
            with patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call') as mock_call:
                mock_call.return_value = self.mock_success_response
                
                for size in SUPPORTED_SIZES:
                    result = await self.server._text2imagev2(
                        prompt="测试",
                        size=size
                    )
                    self.assertEqual(result["status"], "success")
                    self.assertEqual(result["parameters"]["size"], size)
        
        asyncio.run(test_sizes())


class TestAsyncMethods(unittest.IsolatedAsyncioTestCase):
    """
    异步方法测试类
    
    使用IsolatedAsyncioTestCase来测试异步方法，确保异步调用的正确性。
    """

    async def asyncSetUp(self):
        """
        异步测试前的准备工作
        """
        self.test_api_key = "test_api_key_12345"
        
        # 模拟DashScope模块
        with patch('mcp_server_bailian_image.server.dashscope') as mock_dashscope:
            mock_dashscope.api_key = None
            self.server = BailianImageServer(self.test_api_key)
        
        # 模拟成功响应
        self.mock_response = MagicMock()
        self.mock_response.status_code = 200
        self.mock_response.output = MagicMock()
        self.mock_response.output.task_id = "async_test_12345"
        self.mock_response.output.results = [
            MagicMock(url="https://example.com/async_image.jpg")
        ]

    @patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call')
    async def test_async_text2imagev2_call(self, mock_call):
        """
        测试异步调用文生图功能
        
        验证异步方法调用的正确性。
        
        Args:
            mock_call: 模拟的DashScope ImageSynthesis.call方法
        """
        # 设置模拟返回值
        mock_call.return_value = self.mock_response
        
        # 测试参数
        prompt = "异步测试图像生成"
        
        # 异步调用方法
        result = await self.server._text2imagev2(prompt=prompt)
        
        # 验证结果
        self.assertEqual(result["status"], "success")
        self.assertEqual(result["input"]["prompt"], prompt)
        self.assertIn("results", result["output"])
        
        # 验证API被调用
        mock_call.assert_called_once()

    @patch('mcp_server_bailian_image.server.dashscope.ImageSynthesis.call')
    async def test_concurrent_calls(self, mock_call):
        """
        测试并发调用
        
        验证多个异步调用能够正确并发执行。
        
        Args:
            mock_call: 模拟的DashScope ImageSynthesis.call方法
        """
        # 设置模拟返回值
        mock_call.return_value = self.mock_response
        
        # 创建多个并发任务
        tasks = []
        for i in range(3):
            task = self.server._text2imagev2(prompt=f"并发测试图像{i}")
            tasks.append(task)
        
        # 等待所有任务完成
        results = await asyncio.gather(*tasks)
        
        # 验证所有结果
        self.assertEqual(len(results), 3)
        for i, result in enumerate(results):
            self.assertEqual(result["status"], "success")
            self.assertEqual(result["input"]["prompt"], f"并发测试图像{i}")
        
        # 验证API被调用了3次
        self.assertEqual(mock_call.call_count, 3)


def run_tests():
    """
    运行所有测试用例
    
    执行完整的测试套件，包括同步和异步测试。
    """
    print("开始运行阿里云百炼-通义万相图像生成MCP服务器测试...")
    print("=" * 60)
    
    # 创建测试套件
    loader = unittest.TestLoader()
    suite = unittest.TestSuite()
    
    # 添加测试类
    suite.addTests(loader.loadTestsFromTestCase(TestBailianImageServer))
    suite.addTests(loader.loadTestsFromTestCase(TestAsyncMethods))
    
    # 运行测试
    runner = unittest.TextTestRunner(verbosity=2)
    result = runner.run(suite)
    
    print("=" * 60)
    if result.wasSuccessful():
        print("✅ 所有测试通过！图像生成MCP服务器功能正常。")
    else:
        print(f"❌ 测试失败：{len(result.failures)} 个失败，{len(result.errors)} 个错误")
        for failure in result.failures:
            print(f"失败: {failure[0]}")
            print(f"详情: {failure[1]}")
        for error in result.errors:
            print(f"错误: {error[0]}")
            print(f"详情: {error[1]}")
    
    return result.wasSuccessful()


if __name__ == "__main__":
    # 运行测试
    success = run_tests()
    sys.exit(0 if success else 1)


#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
阿里云百炼-通义万相图像生成MCP服务器

本MCP服务器实现了通义万相文生图V2版API的功能，包括：
- 文生图功能（支持正向和反向提示词）
- 多种模型选择（万相2.2、2.1、2.0系列）
- 自定义图像尺寸和生成数量
- 同步调用方式

官方文档：https://help.aliyun.com/zh/model-studio/text-to-image-v2-api-reference

Author: John Chen
"""

import asyncio
import json
import os
import sys
from typing import Any, Dict, List, Optional

try:
    import dashscope
except ImportError:
    print("错误: 请安装DashScope SDK: pip install dashscope")
    sys.exit(1)

from mcp.server import Server
from mcp.server.models import InitializationOptions
from mcp.server.stdio import stdio_server
from mcp.server.lowlevel import NotificationOptions
from mcp.types import (
    Tool,
)

# 阿里云百炼API配置
IMAGE_SYNTHESIS_SERVICE = "aigc"
IMAGE_SYNTHESIS_TASK = "text2image"

# 支持的模型列表
SUPPORTED_MODELS = [
    "wan2.2-t2i-flash",  # 推荐：万相2.2极速版，当前最新模型
    "wan2.2-t2i-plus",   # 推荐：万相2.2专业版，当前最新模型
    "wanx2.1-t2i-turbo", # 万相2.1极速版
    "wanx2.1-t2i-plus",  # 万相2.1专业版
    "wanx2.0-t2i-turbo", # 万相2.0极速版
]

# 支持的图像尺寸
SUPPORTED_SIZES = [
    "512*512", "512*768", "512*1024", "768*512", "768*768", "768*1024",
    "1024*512", "1024*768", "1024*1024", "1024*1440", "1440*1024"
]


class BailianImageServer:
    """
    阿里云百炼-通义万相图像生成MCP服务器

    提供以下功能：
    1. 文生图V2版 - 基于文本提示词生成高质量图像
    2. 支持正向和反向提示词
    3. 多种模型选择（万相2.2、2.1、2.0系列）
    4. 自定义图像尺寸和生成数量
    5. 同步调用方式，快速获取结果

    官方文档：https://help.aliyun.com/zh/model-studio/text-to-image-v2-api-reference
    """

    def __init__(self, api_key: str):
        """
        初始化服务器

        Args:
            api_key: 阿里云百炼API密钥
        """
        self.api_key = api_key
        self.server = Server("bailian-image")
        
        # 配置DashScope
        dashscope.api_key = api_key

        # 注册工具
        self._register_tools()

    def _register_tools(self):
        """
        注册所有MCP工具
        """

        @self.server.list_tools()
        async def list_tools() -> List[Tool]:
            """
            列出所有可用的工具
            """
            return [
                Tool(
                    name="text2imagev2",
                    description="通义万相文生图V2版API。根据文本提示词生成高质量图像，支持正向和反向提示词、多种模型选择、自定义尺寸和生成数量。\n\n示例1 - 基础文生图：\n输入：prompt='一间有着精致窗户的花店，漂亮的木质门，摆放着花朵', model='wan2.2-t2i-flash', size='1024*1024'\n\n示例2 - 使用反向提示词：\n输入：prompt='雪地，白色小教堂，极光，冬日场景，柔和的光线', negative_prompt='人物', model='wan2.2-t2i-flash', size='1024*1024'\n\n官方文档：https://help.aliyun.com/zh/model-studio/text-to-image-v2-api-reference",
                    inputSchema={
                        "type": "object",
                        "properties": {
                            "prompt": {
                                "type": "string",
                                "description": "正向提示词，用来描述生成图像中期望包含的元素和视觉特点。支持中英文，长度不超过800个字符，每个汉字/字母占一个字符，超过部分会自动截断。示例：一只坐着的橘黄色的猫，表情愉悦，活泼可爱，逼真准确。",
                            },
                            "negative_prompt": {
                                "type": "string",
                                "description": "（可选）反向提示词，用来描述不希望在画面中看到的内容，可以对画面进行限制。支持中英文，长度不超过500个字符，超过部分会自动截断。示例值：低分辨率、错误、最差质量、低质量、残缺、多余的手指、比例不良等。",
                            },
                            "model": {
                                "type": "string",
                                "description": "（必选）模型名称。示例值：wan2.2-t2i-turbo。支持的模型包括：万相2.2系列（wan2.2-t2i-flash推荐极速版、wan2.2-t2i-plus推荐专业版）、万相2.1系列（wanx2.1-t2i-turbo极速版、wanx2.1-t2i-plus专业版）、万相2.0系列（wanx2.0-t2i-turbo极速版）。",
                                "enum": SUPPORTED_MODELS,
                                "default": "wan2.2-t2i-flash",
                            },
                            "size": {
                                "type": "string",
                                "description": "（可选）输出图像的分辨率。默认值是1024*1024。图像宽高边长的像素范围为：[512, 1440]，单位像素。可任意组合以设置不同的图像分辨率，最高可达200万像素。",
                                "enum": SUPPORTED_SIZES,
                                "default": "1024*1024",
                            },
                            "n": {
                                "type": "integer",
                                "description": "（可选）生成图片的数量。取值范围为1~4张",
                                "minimum": 1,
                                "maximum": 4,
                                "default": 1,
                            },
                        },
                        "required": ["prompt"],
                    },
                ),
            ]

        @self.server.call_tool()
        async def call_tool(name: str, arguments: Dict[str, Any]) -> Dict[str, Any]:
            """
            调用指定的工具
            """
            if name == "text2imagev2":
                return await self._text2imagev2(**arguments)
            else:
                raise ValueError(f"未知的工具名称: {name}")

    async def _text2imagev2(
        self,
        prompt: str,
        negative_prompt: Optional[str] = None,
        model: str = "wan2.2-t2i-flash",
        size: str = "1024*1024",
        n: int = 1,
    ) -> Dict[str, Any]:
        """
        通义万相文生图V2版API

        Args:
            prompt: 正向提示词，描述期望生成的图像内容
            negative_prompt: 反向提示词，描述不希望出现的内容
            model: 模型名称，默认为wan2.2-t2i-flash
            size: 输出图像尺寸，默认为1024*1024
            n: 生成图片数量，默认为1

        Returns:
            图像生成结果，包含图像URL列表

        Raises:
            Exception: 当API调用失败时抛出异常
        """
        try:
            # 验证模型名称
            if model not in SUPPORTED_MODELS:
                raise ValueError(f"不支持的模型: {model}，支持的模型: {', '.join(SUPPORTED_MODELS)}")

            # 验证图像尺寸
            if size not in SUPPORTED_SIZES:
                raise ValueError(f"不支持的图像尺寸: {size}，支持的尺寸: {', '.join(SUPPORTED_SIZES)}")

            # 验证生成数量
            if not (1 <= n <= 4):
                raise ValueError(f"生成数量必须在1-4之间，当前值: {n}")

            # 根据官方文档，直接传递参数给DashScope SDK
            # 官方示例：ImageSynthesis.call(api_key=os.getenv("DASHSCOPE_API_KEY"), model="wan2.2-t2i-flash", prompt=prompt, n=1, size='1024*1024')
            call_params = {
                "api_key": self.api_key,
                "model": model,
                "prompt": prompt,
                "n": n,
                "size": size,
            }
            
            # 添加反向提示词（如果提供）
            if negative_prompt:
                call_params["negative_prompt"] = negative_prompt

            # 调用DashScope SDK进行同步调用
            response = dashscope.ImageSynthesis.call(**call_params)

            # 检查响应状态
            if response.status_code != 200:
                error_msg = f"API调用失败，状态码: {response.status_code}"
                if hasattr(response, 'message'):
                    error_msg += f"，错误信息: {response.message}"
                raise Exception(error_msg)

            # 解析响应结果
            result = {
                "status": "success",
                "model": model,
                "prompt": prompt,
                "negative_prompt": negative_prompt,
                "size": size,
                "n": n,
                "output": {
                    "task_id": getattr(response.output, "task_id", ""),
                    "results": []
                }
            }

            # 提取图像URL - 根据DashScope SDK的实际响应结构
            if hasattr(response, 'output') and hasattr(response.output, 'results'):
                results = response.output.results
                if isinstance(results, list):
                    for item in results:
                        if hasattr(item, 'url'):
                            result["output"]["results"].append({
                                "url": item.url
                            })
                        elif isinstance(item, dict) and 'url' in item:
                            result["output"]["results"].append({
                                "url": item['url']
                            })
            
            # 如果没有找到results，检查是否有直接的URL字段
            elif hasattr(response, 'output') and hasattr(response.output, 'url'):
                result["output"]["results"].append({
                    "url": response.output.url
                })

            return result

        except Exception as e:
            # 返回错误信息
            return {
                "status": "error",
                "error": str(e),
                "model": model,
                "input": {
                    "prompt": prompt,
                    "negative_prompt": negative_prompt,
                },
                "parameters": {
                    "size": size,
                    "n": n,
                }
            }

    async def run(self):
        """
        运行MCP服务器
        """
        async with stdio_server() as (read_stream, write_stream):
            await self.server.run(
                read_stream,
                write_stream,
                InitializationOptions(
                    server_name="bailian-image",
                    server_version="1.0.0",
                    capabilities=self.server.get_capabilities(
                        notification_options=NotificationOptions(
                            tools_changed=True,
                            resources_changed=False,
                            prompts_changed=False
                        ),
                        experimental_capabilities={}
                    ),
                ),
            )


async def async_main():
    """
    异步主函数，启动MCP服务器
    """
    # 从环境变量或命令行参数获取API密钥
    api_key = os.getenv("DASHSCOPE_API_KEY")

    if not api_key and len(sys.argv) > 1:
        # 检查是否是帮助参数
        if sys.argv[1] in ["--help", "-h"]:
            print("阿里云百炼-通义万相图像生成MCP服务器")
            print("")
            print("使用方法:")
            print(
                "  方式1: export DASHSCOPE_API_KEY=your_api_key && mcp-server-bailian-image"
            )
            print("  方式2: mcp-server-bailian-image your_api_key")
            print("")
            print("支持的功能:")
            print("  - 文生图V2版（支持正向和反向提示词）")
            print("  - 多种模型选择（万相2.2、2.1、2.0系列）")
            print("  - 自定义图像尺寸和生成数量")
            print("  - 同步调用方式")
            print("")
            print("支持的模型:")
            for model in SUPPORTED_MODELS:
                print(f"  - {model}")
            print("")
            print(
                "官方文档: https://help.aliyun.com/zh/model-studio/text-to-image-v2-api-reference"
            )
            return
        else:
            api_key = sys.argv[1]

    if not api_key:
        print("错误: 请提供DASHSCOPE_API_KEY")
        print("使用方法:")
        print(
            "  方式1: export DASHSCOPE_API_KEY=your_api_key && mcp-server-bailian-image"
        )
        print("  方式2: mcp-server-bailian-image your_api_key")
        print("  方式3: mcp-server-bailian-image --help (查看帮助)")
        sys.exit(1)

    # 创建并运行服务器
    server = BailianImageServer(api_key)
    await server.run()


def main():
    """
    同步主函数，用于console_scripts入口点
    """
    asyncio.run(async_main())


if __name__ == "__main__":
    main()